@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-__author__ = '陈章'
-__date__ = '2020/4/13 18:57'
+__author__ = "陈章"
+__date__ = "2020/4/13 18:57"
 
 
 class Cursor:
@@ -20,6 +20,7 @@ class Cursor:
 def get_pymysql_pool(host, port, user, passwd, db, charset, mincached=5):
     import pymysql
     from DBUtils.PooledDB import PooledDB
+
     pool = PooledDB(
         pymysql,
         mincached=mincached,
